@@ -5,7 +5,7 @@ import json
 from django.shortcuts import render
 from django.http import HttpResponse
 from django.views.generic import View
-from .functions import sendSTK
+from .LipaNaMpesaOnline import sendSTK, check_payment_status
 from rest_framework.views import APIView
 from rest_framework.generics import ListCreateAPIView
 from rest_framework.status import HTTP_200_OK, HTTP_400_BAD_REQUEST
@@ -30,7 +30,10 @@ class SubmitView(APIView):
         data = request.data
         phone_number = data['phone_number']
         amount = data['amount']
-        entity_id = data['entity_id']
+
+        entity_id = 0
+        if data.get('entity_id'):
+            entity_id = data.get('entity_id')
 
         transactionId = sendSTK(phone_number, amount, entity_id)
         # b2c()
@@ -38,6 +41,30 @@ class SubmitView(APIView):
         return Response(message, status=HTTP_200_OK)
 
 
+class CheckTransactionOnline(APIView):
+    permission_classes = [AllowAny, ]
+
+    def post(self, request):
+        trans_id = request.data['transaction_id']
+        transaction = PaymentTransaction.objects.filter(id=trans_id).get()
+        try:
+            if transaction.checkoutRequestID:
+                status_response = check_payment_status(transaction.checkoutRequestID)
+                return JsonResponse(
+                    status_response, status=200)
+            else:
+                return JsonResponse({
+                    "message": "Server Error. Transaction not found",
+                    "status": False
+                }, status=400)
+        except PaymentTransaction.DoesNotExist:
+            return JsonResponse({
+                "message": "Server Error. Transaction not found",
+                "status": False
+            },
+                status=400)
+
+
 class CheckTransaction(APIView):
     permission_classes = [AllowAny, ]
 
